#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2006
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ] 
then
  if [  -f ./LI71258.sh ]
 then
 echo "Ifix_LI71258: WVS Ifix LI71258 Installer command syntax: "
 echo "  "
 echo " to install ifix  syntax: ifix_LI71258.sh  -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI71258.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_LI71258: WVS Ifix LI71258 Installer command syntax: "
 echo " to install ifix  syntax: ifix_LI71258 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI71258.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /opt/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   source /opt/WebSphere/AppServer/bin/setupCmdLine.sh
fi
   
   
if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_LI71258: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_LI71258: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/LI71258/wvsapp.ear.bak ] ; then
    echo "Ifix_LI71258: Ifix LI71258 is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
  if [ ! -f $WVS_ROOT/fixes/backup/5.1.3.1/wvsapp.ear ] ; then
    echo "Ifix_LI70860: Pre-requisite Fixpack 5.1.3.1 is not applied, please install Fixpack 5.1.3.1 before trying to install ifix LI71258"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_LI71258: Checking for ifix files ..."
  if [ -f $thisDir/wvsapp.ear ] ; then
    if [ -f $thisDir/libibmgram.so ] ; then
      echo "Ifix_LI71258: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/LI71258
      cp -p $thisDir/LI71258.sh $WVS_ROOT/ifix/ifix_LI71258.sh
      cp -p $thisDir/stopVoiceServer.jacl $WVS_ROOT/ifix/LI71258/stopVoiceServer.jacl
      cp -p $WVS_ROOT/ear/wvsapp.ear $WVS_ROOT/ifix/LI71258/wvsapp.ear.bak
      cp -p $WVS_ROOT/ViaVoice/bin/libibmgram.so $WVS_ROOT/ifix/LI71258/libibmgram.so.bak
      cp -p $WVS_ROOT/ViaVoice/bin/libsmapi.so $WVS_ROOT/ifix/LI71258/libsmapi.so.bak
      cp -p $WVS_ROOT/ViaVoice/bin/libclasser.so $WVS_ROOT/ifix/LI71258/libclasser.so.bak
      cp -p $WVS_ROOT/ViaVoice/bin/libvvgp.so $WVS_ROOT/ifix/LI71258/libvvgp.so.bak
      cp -p $WVS_ROOT/ViaVoice/bin/engine $WVS_ROOT/ifix/LI71258/engine.bak
      cp -p $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ifix/LI71258/installEar.jacl.bak
      
      echo "Ifix_LI71258: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI71258: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_LI71258: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/LI71258
         exit -1
      fi
      
      cp -fbp $thisDir/wvsapp.ear $WVS_ROOT/ear/. 
      cp -fbp $thisDir/libibmgram.so $WVS_ROOT/ViaVoice/bin/.
      cp -fbp $thisDir/libsmapi.so $WVS_ROOT/ViaVoice/bin/.
      cp -fbp $thisDir/libclasser.so $WVS_ROOT/ViaVoice/bin/.
      cp -fbp $thisDir/libvvgp.so $WVS_ROOT/ViaVoice/bin/.
      cp -fbp $thisDir/engine $WVS_ROOT/ViaVoice/bin/.
      cp -fbp $thisDir/installEar.jacl $WVS_ROOT/.package/.
      
      chmod 755 $WVS_ROOT/ViaVoice/bin/engine

      echo "Ifix_LI71258: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI71258: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_LI71258: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi

      echo "Ifix_LI71258: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $thisDir/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?
      
      echo "Ifix_LI71258: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
      errorsduringinstall=$?
      
      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_LI71258: Ifix is now applied, please reboot the system"
      else
        echo "Ifix_LI71258: Ifix installation was not successful. Please uninstall. "
      fi
      
    else
      echo "Ifix_LI71258: Ifix files missing, please be sure this script is in same directory as the binary files" 
    fi
  fi
  cp -fp $thisDir/LI71258.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_LI71258: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/LI71258/wvsapp.ear.bak ] ; then
    if [ -f $WVS_ROOT/ifix/LI71258/libibmgram.so.bak ] ; then
      echo "Ifix_LI71258: Ifix backup files found.. proceeding to un-install ifix"

      
      echo "Ifix_LI71258: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI71258: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_LI71258: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/LI71258
         exit -1
      fi
      
      cp -fp $WVS_ROOT/ifix/LI71258/wvsapp.ear.bak $WVS_ROOT/ear/wvsapp.ear
      cp -fp $WVS_ROOT/ifix/LI71258/libibmgram.so.bak  $WVS_ROOT/ViaVoice/bin/libibmgram.so
      cp -fp $WVS_ROOT/ifix/LI71258/libsmapi.so.bak  $WVS_ROOT/ViaVoice/bin/libsmapi.so
      cp -fp $WVS_ROOT/ifix/LI71258/libclasser.so.bak  $WVS_ROOT/ViaVoice/bin/libclasser.so
      cp -fp $WVS_ROOT/ifix/LI71258/libvvgp.so.bak  $WVS_ROOT/ViaVoice/bin/libsmapi.so
      cp -fp $WVS_ROOT/ifix/LI71258/engine.bak  $WVS_ROOT/ViaVoice/bin/engine

      chmod 755 $WVS_ROOT/ViaVoice/bin/engine
          
      echo "Ifix_LI71258: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI71258: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_LI71258: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi
       
      echo "Ifix_LI71258: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/LI71258/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?
          
      echo "Ifix_LI71258: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
      errorsduringinstall=$?
      
      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_LI71258: Ifix is now uninstalled, please reboot the system"
        echo "Ifix_LI71258:  Please remove the $WVS_ROOT/ifix/LI71258 directory before attempting a subsequent install of this ifix."
      else
        echo "Ifix_LI71258: Ifix uninstallation was not successful. Please contact support. "
      fi
      
    else
      echo "Ifix_LI71258: Ifix backup files missing, uninstall not performed"
    fi
  else
    echo "Ifix_LI71258: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
